@@ -24,3 +24,11 @@ def test_can_render_notebook(filename):
         ["mkdocs", "build", "-q", "-f", f"{filename}"], cwd=mkdocs_dir
     )
     assert run.returncode == 0
+
+
+def test_fails_when_configured_to_fail():
+    this_dir = os.path.dirname(os.path.realpath(__file__))
+    mkdocs_dir = os.path.join(this_dir, "mkdocs")
+    cmd = ["mkdocs", "build", "-q", "-f", "base-with-nbs-failure.yml"]
+    result = subprocess.run(cmd, cwd=mkdocs_dir)
+    assert result.returncode != 0
